Skip to contents

Inspect Gazepoint columns

Usage

inspect_gazepoint_columns(x)

Arguments

x

A data frame or path to a Gazepoint CSV export.

Value

A tibble describing column names, semantic groups, and missingness.