Guardrail for threshold-free cluster enhancement
Source:R/cluster_permutation_extensions.R
run_gazepoint_tfce.RdThis function intentionally fails safely. TFCE is not implemented as an active inferential engine in gp3tools.
R/cluster_permutation_extensions.R
run_gazepoint_tfce.RdThis function intentionally fails safely. TFCE is not implemented as an active inferential engine in gp3tools.