Skip to contents

Export model-summary tables and optional estimated marginal means tables to CSV files. The function is designed for objects returned by tidy_gazepoint_model_summary() and summarise_gazepoint_emmeans().

Usage

export_gazepoint_model_tables(
  model_summary = NULL,
  emmeans_summary = NULL,
  output_dir,
  prefix = "gazepoint_model",
  overwrite = TRUE,
  include_diagnostics = TRUE
)

Arguments

model_summary

Optional object returned by tidy_gazepoint_model_summary().

emmeans_summary

Optional object returned by summarise_gazepoint_emmeans().

output_dir

Output directory.

prefix

File-name prefix.

overwrite

Logical. If FALSE, existing output files cause an error.

include_diagnostics

Logical. If TRUE, export available diagnostic component tables from model_summary.

Value

A tibble indexing the written files.