R/gp3tools.R
inspect_gazepoint_columns.Rd
Inspect Gazepoint columns
inspect_gazepoint_columns(x)
A data frame or path to a Gazepoint CSV export.
A tibble describing column names, semantic groups, and missingness.